%global 	commit 5343e4e150bc90960a6aece285fa06f30888ee7e
%global 	shortcommit %(c=%{commit}; echo ${c:0:7})

Name:           fricas
Version:	1.3.11.%{shortcommit}
Release:        2
Summary:	FriCAS is an advanced computer algebra system. 

License:	BSD-3-Clause
URL:		https://fricas.github.io
Source0:        https://github.com/%{name}/%{name}/archive/%{commit}/%{name}-%{shortcommit}.tar.gz

BuildRequires:	make
BuildRequires:	gcc
BuildRequires:	sbcl
BuildRequires:	gmp-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
# For reading build-id
BuildRequires:  elfutils
# For objcopy (used to fix build-id conflicts)
BuildRequires:  binutils

# graphics
BuildRequires:  ImageMagick
BuildRequires:	gnuplot
BuildRequires:	libX11-devel
BuildRequires:	xorg-x11-server-Xvfb
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xpm)
# Latex https://fricas.github.io/install.html#latex-optional
BuildRequires:	tex(amsmath.sty)
BuildRequires:  tex(breqn.sty)
BuildRequires:  tex(tensor.sty)
BuildRequires:  tex(mleftright.sty)
BuildRequires:  tex(epsf.sty)
BuildRequires:	tex(verbatim.sty)
BuildRequires:	tex(hyperref.sty)
BuildRequires: 	tex(color.sty)
BuildRequires: 	tex(listings.sty)
BuildRequires: 	tex(makeidx.sty)
BuildRequires: 	tex(xparse.sty)
BuildRequires:	tex(tikz.sty)
BuildRequires:  tex(framed.sty)
BuildRequires:  texlive-dvips
BuildRequires:	texlive-dvipng
BuildRequires:  texlive-latex
BuildRequires:  texlive-makeindex
BuildRequires:  texlive-pdftex
#emacs  
Requires:       emacs
Requires:	emacs-auctex
Requires:       gnuplot

%description
FriCAS is an advanced computer algebra system, is a fork (2007) of the Axiom computer algebra system.


%prep
%autosetup -n %{name}-%{commit}


%build
%configure --with-lisp="sbcl --control-stack-size 512 --dynamic-space-size 6000" --enable-FEATURE --enable-gmp --with-x --enable-algebra-optimization="((speed 3) (safety 0))"
%make_build MAYBE_VIEWPORTS=viewports


%install
%make_install

# Fix build-id conflict by modifying the FRICASsys binary with an additional dummy section
fricas_bin=%{buildroot}%{_libdir}/fricas/target/x86_64-redhat-linux-gnu/bin/FRICASsys

echo "Original build-id:"
eu-readelf -n $fricas_bin | grep 'Build ID' || echo "No build-id found"

# Create dummy section content
echo "fix" > fricasfix.txt

# Add dummy section to alter ELF hash and produce a unique build-id
objcopy --add-section .fricasfix=fricasfix.txt \
        --set-section-flags .fricasfix=noload,readonly \
        $fricas_bin

echo "New build-id:"
eu-readelf -n $fricas_bin | grep 'Build ID' || echo "Failed to read new build-id"

%check
# Basic runtime check
%{buildroot}%{_bindir}/fricas --version > /dev/null || echo "fricas --version failed"
%{buildroot}%{_bindir}/efricas --version > /dev/null || echo "efricas --version failed"



%files
%license LICENSE.txt
%doc ChangeLog README.rst
%{_bindir}/fricas
%{_bindir}/efricas
%{_libdir}/fricas




%changelog
* Fri Apr 11 2025 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.11.%{shortcommit}-2
- Added a dummy ELF section to FRICASsys to regenerate build-id and resolve file conflict with sbcl
- Added basic runtime version checks to %%check

* Thu Apr 10 2025 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.11.%{shortcommit}-1
- rebuild by last commit 07 Apr 2025, and with sbcl 2.5.3

* Fri Nov 01 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.11.%{shortcommit}-1
- rebuild by last commit 01 Nov 2024

* Sun Oct 27 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.11.%{shortcommit}-1
- rebuild by last commit 27 Oct 2024

* Wed Jul 17 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.11.%{shortcommit}-1
- rebuild by last commit 17 Jul 2024

* Sat Jun 15 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.10.%{shortcommit}-2
- rebuild by last commit 12 Jun 2024

* Thu Jun  6 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.10.%{shortcommit}-1
- rebuild with new version sbcl 2.4.5 and update with commit above

* Mon May  6 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.10-5
- rebuid with new version sbcl 2.4.4

* Tue Apr 23 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.10-4
- rebuild with new version sbcl 2.4.3

* Sat Mar  9 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.10-3
- rebuild with new version sbcl 2.4.2

* Wed Jan 31 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.10-2
- rebuild with new version sbcl

* Sun Jan 14 2024 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.10-1
- update to 1.3.10

* Fri Dec 29 2023 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.9.%{shortcommit}-1
* rebuild with new version sbcl and update with commit above

* Fri Dec 15 2023 Ilia Gradina <ilgrad@fedoraproject.org> - 1.3.9.%{shortcommit}-1
- init commit from 14.12.2023

